@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 
 from __future__ import print_function
-from alibuild_helpers.log import debug, error, banner, info, success, warning, dieOnError
-from alibuild_helpers.utilities import parseDefaults, readDefaults, getPackageList, validateDefaults, dockerStatusOutput, format
-from alibuild_helpers.cmd import getStatusOutputBash, execute
+from alibuild_helpers.log import debug, error, info, dieOnError
+from alibuild_helpers.utilities import parseDefaults, readDefaults, getPackageList, validateDefaults, format
+from alibuild_helpers.cmd import DockerRunner, execute
 from tempfile import NamedTemporaryFile
 from os import remove
 
@@ -20,24 +20,25 @@ def doDeps(args, parser):
 
   # Resolve all the package parsing boilerplate
   specs = {}
-  defaultsReader = lambda: readDefaults(args.configDir, args.defaults, parser.error)
+  defaultsReader = lambda: readDefaults(args.configDir, args.defaults, parser.error, args.architecture)
   (err, overrides, taps) = parseDefaults(args.disable, defaultsReader, debug)
-  (systemPackages, ownPackages, failed, validDefaults) = \
-    getPackageList(packages                = [args.package],
-                   specs                   = specs,
-                   configDir               = args.configDir,
-                   preferSystem            = args.preferSystem,
-                   noSystem                = args.noSystem,
-                   architecture            = args.architecture,
-                   disable                 = args.disable,
-                   defaults                = args.defaults,
-                   dieOnError              = dieOnError,
-                   performPreferCheck      = lambda pkg, cmd : dockerStatusOutput(cmd, dockerImage, executor = getStatusOutputBash),
-                   performRequirementCheck = lambda pkg, cmd : dockerStatusOutput(cmd, dockerImage, executor = getStatusOutputBash),
-                   performValidateDefaults = lambda spec : validateDefaults(spec, args.defaults),
-                   overrides               = overrides,
-                   taps                    = taps,
-                   log                     = debug)
+  with DockerRunner(dockerImage, ["--network=host"]) as getstatusoutput_docker:
+    systemPackages, ownPackages, failed, validDefaults = \
+      getPackageList(packages                = [args.package],
+                     specs                   = specs,
+                     configDir               = args.configDir,
+                     preferSystem            = args.preferSystem,
+                     noSystem                = args.noSystem,
+                     architecture            = args.architecture,
+                     disable                 = args.disable,
+                     defaults                = args.defaults,
+                     performPreferCheck      = lambda pkg, cmd: getstatusoutput_docker(cmd),
+                     performRequirementCheck = lambda pkg, cmd: getstatusoutput_docker(cmd),
+                     performValidateDefaults = lambda spec: validateDefaults(spec, args.defaults),
+                     overrides               = overrides,
+                     taps                    = taps,
+                     log                     = debug)
+
   dieOnError(validDefaults and args.defaults not in validDefaults,
              "Specified default `%s' is not compatible with the packages you want to build.\n" % args.defaults +
              "Valid defaults:\n\n- " +
@@ -93,14 +94,18 @@ def doDeps(args, parser):
   fp.write(dot)
   fp.close()
 
+  # Check if we have dot in PATH
+  try:
+    execute(["dot", "-V"])
+  except Exception as e:
+    dieOnError(True, "Could not find dot in PATH. Please install graphviz and add it to PATH.")
   try:
     if args.neat:
       execute(format("tred %(dotFile)s > %(dotFile)s.0 && mv %(dotFile)s.0 %(dotFile)s",
               dotFile=fp.name))
     execute(["dot", fp.name, "-Tpdf", "-o", args.outgraph])
   except Exception as e:
-    error(format("Error generating dependencies with dot: %(type)s: %(msg)s",
-                 type=type(e).__name__, msg=str(e)))
+    error("Error generating dependencies with dot: %s: %s", type(e).__name__, e)
   else:
     info("Dependencies graph generated: %s" % args.outgraph)
   if fp.name != args.outdot:
