@@ -1,17 +1,11 @@
 #!/usr/bin/env python
 import os, re, sys
 from os.path import exists, abspath, expanduser
-try:
-  from commands import getstatusoutput
-except ImportError:
-  from subprocess import getstatusoutput
 import logging
 from alibuild_helpers.log import debug, error, banner, info, success, warning
 from alibuild_helpers.log import logger
-from alibuild_helpers.utilities import getPackageList, format, detectArch, parseDefaults, readDefaults, validateDefaults
-from alibuild_helpers.utilities import dockerStatusOutput
-from alibuild_helpers.cmd import getStatusOutputBash
-import subprocess
+from alibuild_helpers.utilities import getPackageList, parseDefaults, readDefaults, validateDefaults
+from alibuild_helpers.cmd import getstatusoutput, DockerRunner
 
 def prunePaths(workDir):
   for x in ["PATH", "LD_LIBRARY_PATH", "DYLD_LIBRARY_PATH"]:
@@ -20,12 +14,12 @@ def prunePaths(workDir):
     workDirEscaped = re.escape("%s" % workDir) + "[^:]*:?"
     os.environ[x] = re.sub(workDirEscaped, "", os.environ[x])
 
-def checkPreferSystem(spec, cmd, homebrew_replacement, dockerImage):
+def checkPreferSystem(spec, cmd, homebrew_replacement, getstatusoutput_docker):
     if cmd == "false":
       debug("Package %s can only be managed via alibuild.", spec["package"])
       return (1, "")
     cmd = homebrew_replacement + cmd
-    err, out = dockerStatusOutput(cmd, dockerImage=dockerImage, executor=getStatusOutputBash)
+    err, out = getstatusoutput_docker(cmd)
     if not err:
       success("Package %s will be picked up from the system.", spec["package"])
       for x in out.split("\n"):
@@ -38,12 +32,12 @@ def checkPreferSystem(spec, cmd, homebrew_replacement, dockerImage):
             spec["package"], cmd, "\n".join("%s: %s" % (spec["package"], x) for x in out.split("\n")))
     return (err, "")
 
-def checkRequirements(spec, cmd, homebrew_replacement, dockerImage):
+def checkRequirements(spec, cmd, homebrew_replacement, getstatusoutput_docker):
     if cmd == "false":
       debug("Package %s is not a system requirement.", spec["package"])
       return (0, "")
     cmd = homebrew_replacement + cmd
-    err, out = dockerStatusOutput(cmd, dockerImage=dockerImage, executor=getStatusOutputBash)
+    err, out = getstatusoutput_docker(cmd)
     if not err:
       success("Required package %s will be picked up from the system.", spec["package"])
       debug("%s", cmd)
@@ -72,31 +66,6 @@ def systemInfo():
     if not err:
       debug("%s:\n%s", f, out)
 
-def doctorArgParser(parser):
-  parser.add_argument("-a", "--architecture", help="force architecture",
-                      dest="architecture", default=detectArch())
-  parser.add_argument("-c", "--config", help="path to alidist",
-                      dest="configDir", default="alidist")
-  parser.add_argument("-w", "--work-dir", help="path to work dir",
-                      dest="workDir", default="workDir")
-  parser.add_argument("--defaults", default="release",
-                      dest="defaults", help="Specify default to use")
-  parser.add_argument("--disable", dest="disable", default=[],
-                      metavar="PACKAGE", action="append",
-                      help="Do not build PACKAGE and all its (unique) dependencies.")
-  parser.add_argument("--always-prefer-system", dest="preferSystem", default=False,
-                      action="store_true", help="Always use system packages when compatible")
-  parser.add_argument("--no-system", dest="noSystem", default=False,
-                      action="store_true", help="Never use system packages")
-  parser.add_argument("packages", nargs="+", help="Package to test",
-                      default=[])
-  parser.add_argument("--docker", dest="docker", action="store_true", default=False)
-  parser.add_argument("--docker-image", dest="dockerImage",
-                      help="Image to use in case you build with docker (implies --docker)")
-  parser.add_argument("--chdir", "-C", help="Change to the specified directory first",
-                      metavar="DIR", dest="chdir", default=os.environ.get("ALIBUILD_CHDIR", "."))
-  return parser
-
 def doDoctor(args, parser):
   if not exists(args.configDir):
     parser.error("Wrong path to alidist specified: %s" % args.configDir)
@@ -160,8 +129,6 @@ def doDoctor(args, parser):
   systemInfo()
 
   specs = {}
-  def unreachable():
-    assert(False)
   defaultsReader = lambda : readDefaults(args.configDir, args.defaults, parser.error, args.architecture)
   (err, overrides, taps) = parseDefaults(args.disable, defaultsReader, info)
   if err:
@@ -174,21 +141,22 @@ def doDoctor(args, parser):
       error("%s", msg)
     return (ok,msg,valid)
 
-  (fromSystem, own, failed, validDefaults) = getPackageList(packages                = packages,
-                                                            specs                   = specs,
-                                                            configDir               = args.configDir,
-                                                            preferSystem            = args.preferSystem,
-                                                            noSystem                = args.noSystem,
-                                                            architecture            = args.architecture,
-                                                            disable                 = args.disable,
-                                                            defaults                = args.defaults,
-                                                            dieOnError              = lambda x, y : unreachable,
-                                                            performPreferCheck      = lambda pkg, cmd : checkPreferSystem(pkg, cmd, homebrew_replacement, dockerImage),
-                                                            performRequirementCheck = lambda pkg, cmd : checkRequirements(pkg, cmd, homebrew_replacement, dockerImage),
-                                                            performValidateDefaults = performValidateDefaults,
-                                                            overrides               = overrides,
-                                                            taps                    = taps,
-                                                            log                     = info)
+  with DockerRunner(dockerImage, ["--network=host"]) as getstatusoutput_docker:
+    fromSystem, own, failed, validDefaults = \
+      getPackageList(packages                = packages,
+                     specs                   = specs,
+                     configDir               = args.configDir,
+                     preferSystem            = args.preferSystem,
+                     noSystem                = args.noSystem,
+                     architecture            = args.architecture,
+                     disable                 = args.disable,
+                     defaults                = args.defaults,
+                     performPreferCheck      = lambda pkg, cmd: checkPreferSystem(pkg, cmd, homebrew_replacement, getstatusoutput_docker),
+                     performRequirementCheck = lambda pkg, cmd: checkRequirements(pkg, cmd, homebrew_replacement, getstatusoutput_docker),
+                     performValidateDefaults = performValidateDefaults,
+                     overrides               = overrides,
+                     taps                    = taps,
+                     log                     = info)
 
   alwaysBuilt = set(x for x in specs) - fromSystem - own - failed
   if alwaysBuilt:
