@@ -1,12 +1,11 @@
 from alibuild_helpers.cmd import execute
-from alibuild_helpers.utilities import format
-from alibuild_helpers.utilities import parseRecipe, getPackageList, getRecipeReader, parseDefaults, readDefaults, validateDefaults
+from alibuild_helpers.git import git
+from alibuild_helpers.utilities import getPackageList, parseDefaults, readDefaults, validateDefaults
 from alibuild_helpers.log import debug, error, warning, banner, info
 from alibuild_helpers.log import dieOnError
-from alibuild_helpers.git import partialCloneFilter
 from alibuild_helpers.workarea import updateReferenceRepoSpec
 
-from os.path import abspath, basename, join
+from os.path import join
 import os.path as path
 import os, sys
 try:
@@ -26,32 +25,30 @@ def doInit(args):
   assert(type(pkgs) == list)
   if args.dryRun:
     info("This will initialise local checkouts for %s\n"
-         "--dry-run / -n specified. Doing nothing." % ",".join(x["name"] for x in pkgs))
+         "--dry-run / -n specified. Doing nothing.", ",".join(x["name"] for x in pkgs))
     sys.exit(0)
   try:
     path.exists(args.develPrefix) or os.mkdir(args.develPrefix)
     path.exists(args.referenceSources) or os.makedirs(args.referenceSources)
   except OSError as e:
-    error(str(e))
+    error("%s", e)
     sys.exit(1)
 
   # Fetch recipes first if necessary
   if path.exists(args.configDir):
-    warning("using existing recipes from %s" % args.configDir)
+    warning("using existing recipes from %s", args.configDir)
   else:
-    cmd = format("git clone %(pcf)s %(repo)s%(branch)s %(cd)s",
-                 pcf=partialCloneFilter,
-                 repo=args.dist["repo"] if ":" in args.dist["repo"] else "https://github.com/%s" % args.dist["repo"],
-                 branch=" -b "+args.dist["ver"] if args.dist["ver"] else "",
-                 cd=args.configDir)
-    debug(cmd)
-    err = execute(cmd)
-    dieOnError(err!=0, "cannot clone recipes")
+    cmd = ["clone", "--origin", "upstream",
+           args.dist["repo"] if ":" in args.dist["repo"] else "https://github.com/" + args.dist["repo"]]
+    if args.dist["ver"]:
+      cmd.extend(["-b", args.dist["ver"]])
+    cmd.append(args.configDir)
+    git(cmd)
 
   # Use standard functions supporting overrides and taps. Ignore all disables
   # and system packages as they are irrelevant in this context
   specs = {}
-  defaultsReader = lambda: readDefaults(args.configDir, args.defaults, error)
+  defaultsReader = lambda: readDefaults(args.configDir, args.defaults, lambda msg: error("%s", msg), args.architecture)
   (err, overrides, taps) = parseDefaults([], defaultsReader, debug)
   (_,_,_,validDefaults) = getPackageList(packages=[ p["name"] for p in pkgs ],
                                          specs=specs,
@@ -61,7 +58,6 @@ def doInit(args):
                                          architecture="",
                                          disable=[],
                                          defaults=args.defaults,
-                                         dieOnError=dieOnError,
                                          performPreferCheck=lambda *x, **y: (1, ""),
                                          performRequirementCheck=lambda *x, **y: (0, ""),
                                          performValidateDefaults=lambda spec : validateDefaults(spec, args.defaults),
@@ -80,24 +76,20 @@ def doInit(args):
     writeRepo = spec.get("write_repo", spec.get("source"))
     dieOnError(not writeRepo, "package %s has no source field and cannot be developed" % spec["package"])
     if path.exists(dest):
-      warning("not cloning %s since it already exists" % spec["package"])
+      warning("not cloning %s since it already exists", spec["package"])
       continue
     p["ver"] = p["ver"] if p["ver"] else spec.get("tag", spec["version"])
-    debug("cloning %s%s for development" % (spec["package"], " version "+p["ver"] if p["ver"] else ""))
+    debug("cloning %s%s for development", spec["package"], " version "+p["ver"] if p["ver"] else "")
 
-    updateReferenceRepoSpec(args.referenceSources, spec["package"], spec, True)
-    cmd = format("git clone %(pcf)s %(readRepo)s%(branch)s --reference %(refSource)s %(cd)s && " +
-                 "cd %(cd)s && git remote set-url --push origin %(writeRepo)s",
-                 pcf=partialCloneFilter,
-                 readRepo=spec["source"],
-                 writeRepo=writeRepo,
-                 branch=" -b "+p["ver"] if p["ver"] else "",
-                 refSource=join(args.referenceSources, spec["package"].lower()),
-                 cd=dest)
-    debug(cmd)
-    err = execute(cmd)
-    dieOnError(err!=0, "cannot clone %s%s" %
-                       (spec["package"], " version "+p["ver"] if p["ver"] else ""))
+    updateReferenceRepoSpec(args.referenceSources, spec["package"], spec, True, False)
+
+    cmd = ["clone", "--origin", "upstream", spec["source"],
+           "--reference", join(args.referenceSources, spec["package"].lower())]
+    if p["ver"]:
+      cmd.extend(["-b", p["ver"]])
+    cmd.append(dest)
+    git(cmd)
+    git(("remote", "set-url", "--push", "upstream", writeRepo), directory=dest)
 
     # Make it point relatively to the mirrors for relocation: as per Git specifics, the path has to
     # be relative to the repository's `.git` directory. Don't do it if no common path is found
@@ -109,6 +101,5 @@ def doInit(args):
       with open(repoAltConf, "w") as fil:
         fil.write(os.path.relpath(refObjects, repoObjects) + "\n")
 
-  banner(format("Development directory %(d)s created%(pkgs)s",
-         pkgs=" for "+", ".join([ x["name"].lower() for x in pkgs ]) if pkgs else "",
-         d=args.develPrefix))
+  banner("Development directory %s created%s", args.develPrefix,
+         " for "+", ".join(x["name"].lower() for x in pkgs) if pkgs else "")
